==> jc-1.4.0.tar.gz: javax/crypto/SecretKeyFactorySpi.h <==
// public abstract class javax.crypto.SecretKeyFactorySpi

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d672333b6b908575 javax_crypto_SecretKeyFactorySpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_SecretKeyFactorySpi_H_
#define _JC_javax_crypto_SecretKeyFactorySpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_spec_KeySpec$object;
struct _jc_javax_crypto_SecretKey$object;

// Typedefs
typedef struct _jc_javax_crypto_SecretKeyFactorySpi$sub_refs	_jc_javax_crypto_SecretKeyFactorySpi$sub_refs;
typedef struct _jc_javax_crypto_SecretKeyFactorySpi$sub_nonrefs	_jc_javax_crypto_SecretKeyFactorySpi$sub_nonrefs;
typedef struct _jc_javax_crypto_SecretKeyFactorySpi$refs	_jc_javax_crypto_SecretKeyFactorySpi$refs;
typedef struct _jc_javax_crypto_SecretKeyFactorySpi$nonrefs	_jc_javax_crypto_SecretKeyFactorySpi$nonrefs;
typedef struct _jc_javax_crypto_SecretKeyFactorySpi$object	_jc_javax_crypto_SecretKeyFactorySpi$object;

typedef const struct _jc_javax_crypto_SecretKeyFactorySpi$vmethods	_jc_javax_crypto_SecretKeyFactorySpi$vmethods;
typedef const struct _jc_javax_crypto_SecretKeyFactorySpi$vtable	_jc_javax_crypto_SecretKeyFactorySpi$vtable;
typedef const struct _jc_javax_crypto_SecretKeyFactorySpi$vtype	_jc_javax_crypto_SecretKeyFactorySpi$vtype;

// Constructors
extern void _jc_javax_crypto_SecretKeyFactorySpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_crypto_SecretKeyFactorySpi$object *);

// Virtual methods
extern struct _jc_object *_jc_javax_crypto_SecretKeyFactorySpi$method$engineGenerateSecret$8fd98bf1956dbe34(_jc_env *, struct _jc_javax_crypto_SecretKeyFactorySpi$object *, struct _jc_object *);
extern struct _jc_object *_jc_javax_crypto_SecretKeyFactorySpi$method$engineGetKeySpec$d2cdb5eb64c644b0(_jc_env *, struct _jc_javax_crypto_SecretKeyFactorySpi$object *, struct _jc_object *, struct _jc_java_lang_Class$object *);
extern struct _jc_object *_jc_javax_crypto_SecretKeyFactorySpi$method$engineTranslateKey$84d30673c54d8d42(_jc_env *, struct _jc_javax_crypto_SecretKeyFactorySpi$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_SecretKeyFactorySpi$method_info$engineGenerateSecret$8fd98bf1956dbe34;
extern _jc_method _jc_javax_crypto_SecretKeyFactorySpi$method_info$engineGetKeySpec$d2cdb5eb64c644b0;
extern _jc_method _jc_javax_crypto_SecretKeyFactorySpi$method_info$engineTranslateKey$84d30673c54d8d42;

// Virtual methods structure
struct _jc_javax_crypto_SecretKeyFactorySpi$vmethods {
	struct _jc_object	*(*engineGenerateSecret$8fd98bf1956dbe34)(_jc_env *, struct _jc_javax_crypto_SecretKeyFactorySpi$object *, struct _jc_object *);
	struct _jc_object	*(*engineGetKeySpec$d2cdb5eb64c644b0)(_jc_env *, struct _jc_javax_crypto_SecretKeyFactorySpi$object *, struct _jc_object *, struct _jc_java_lang_Class$object *);
	struct _jc_object	*(*engineTranslateKey$84d30673c54d8d42)(_jc_env *, struct _jc_javax_crypto_SecretKeyFactorySpi$object *, struct _jc_object *);
};

// Vtable
struct _jc_javax_crypto_SecretKeyFactorySpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_SecretKeyFactorySpi$vmethods	javax_crypto_SecretKeyFactorySpi;
};

// Vtype
struct _jc_javax_crypto_SecretKeyFactorySpi$vtype {
	_jc_type			type;
	_jc_javax_crypto_SecretKeyFactorySpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_SecretKeyFactorySpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_crypto_SecretKeyFactorySpi$refs {
    _jc_javax_crypto_SecretKeyFactorySpi$sub_refs	javax_crypto_SecretKeyFactorySpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_SecretKeyFactorySpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_SecretKeyFactorySpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_SecretKeyFactorySpi$sub_nonrefs	javax_crypto_SecretKeyFactorySpi;
};

// Object instance structure
struct _jc_javax_crypto_SecretKeyFactorySpi$object {
	_jc_javax_crypto_SecretKeyFactorySpi$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_SecretKeyFactorySpi$vtype	*vtype;
	_jc_javax_crypto_SecretKeyFactorySpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_SecretKeyFactorySpi$vtype _jc_javax_crypto_SecretKeyFactorySpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_SecretKeyFactorySpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_SecretKeyFactorySpi$class_object;

#endif	/* _JC_javax_crypto_SecretKeyFactorySpi_H_ */

==> jc-1.4.6.tar.gz: javax/crypto/SecretKeyFactorySpi.h <==
// public abstract class javax.crypto.SecretKeyFactorySpi

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d672333b6b908575 javax_crypto_SecretKeyFactorySpi

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_SecretKeyFactorySpi_H_
#define _JC_javax_crypto_SecretKeyFactorySpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_spec_KeySpec$object;
struct _jc_javax_crypto_SecretKey$object;

// Typedefs
typedef struct _jc_javax_crypto_SecretKeyFactorySpi$sub_refs	_jc_javax_crypto_SecretKeyFactorySpi$sub_refs;
typedef struct _jc_javax_crypto_SecretKeyFactorySpi$sub_nonrefs	_jc_javax_crypto_SecretKeyFactorySpi$sub_nonrefs;
typedef struct _jc_javax_crypto_SecretKeyFactorySpi$refs	_jc_javax_crypto_SecretKeyFactorySpi$refs;
typedef struct _jc_javax_crypto_SecretKeyFactorySpi$nonrefs	_jc_javax_crypto_SecretKeyFactorySpi$nonrefs;
typedef struct _jc_javax_crypto_SecretKeyFactorySpi$object	_jc_javax_crypto_SecretKeyFactorySpi$object;

typedef const struct _jc_javax_crypto_SecretKeyFactorySpi$vmethods	_jc_javax_crypto_SecretKeyFactorySpi$vmethods;
typedef const struct _jc_javax_crypto_SecretKeyFactorySpi$vtable	_jc_javax_crypto_SecretKeyFactorySpi$vtable;
typedef const struct _jc_javax_crypto_SecretKeyFactorySpi$vtype	_jc_javax_crypto_SecretKeyFactorySpi$vtype;

// Constructors
extern void _jc_javax_crypto_SecretKeyFactorySpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_crypto_SecretKeyFactorySpi$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_crypto_SecretKeyFactorySpi$method$engineGenerateSecret$8fd98bf1956dbe34(_jc_env *, struct _jc_javax_crypto_SecretKeyFactorySpi$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_crypto_SecretKeyFactorySpi$method$engineGetKeySpec$d2cdb5eb64c644b0(_jc_env *, struct _jc_javax_crypto_SecretKeyFactorySpi$object *, struct _jc_object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_crypto_SecretKeyFactorySpi$method$engineTranslateKey$84d30673c54d8d42(_jc_env *, struct _jc_javax_crypto_SecretKeyFactorySpi$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_SecretKeyFactorySpi$method_info$engineGenerateSecret$8fd98bf1956dbe34;
extern _jc_method _jc_javax_crypto_SecretKeyFactorySpi$method_info$engineGetKeySpec$d2cdb5eb64c644b0;
extern _jc_method _jc_javax_crypto_SecretKeyFactorySpi$method_info$engineTranslateKey$84d30673c54d8d42;

// Virtual methods structure
struct _jc_javax_crypto_SecretKeyFactorySpi$vmethods {
	struct _jc_object	*(*engineGenerateSecret$8fd98bf1956dbe34)(_jc_env *, struct _jc_javax_crypto_SecretKeyFactorySpi$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*engineGetKeySpec$d2cdb5eb64c644b0)(_jc_env *, struct _jc_javax_crypto_SecretKeyFactorySpi$object *, struct _jc_object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*engineTranslateKey$84d30673c54d8d42)(_jc_env *, struct _jc_javax_crypto_SecretKeyFactorySpi$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_crypto_SecretKeyFactorySpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_SecretKeyFactorySpi$vmethods	javax_crypto_SecretKeyFactorySpi;
};

// Vtype
struct _jc_javax_crypto_SecretKeyFactorySpi$vtype {
	_jc_type			type;
	_jc_javax_crypto_SecretKeyFactorySpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_SecretKeyFactorySpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_crypto_SecretKeyFactorySpi$refs {
    _jc_javax_crypto_SecretKeyFactorySpi$sub_refs	javax_crypto_SecretKeyFactorySpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_SecretKeyFactorySpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_SecretKeyFactorySpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_SecretKeyFactorySpi$sub_nonrefs	javax_crypto_SecretKeyFactorySpi;
};

// Object instance structure
struct _jc_javax_crypto_SecretKeyFactorySpi$object {
	_jc_javax_crypto_SecretKeyFactorySpi$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_SecretKeyFactorySpi$vtype	*vtype;
	_jc_javax_crypto_SecretKeyFactorySpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_SecretKeyFactorySpi$vtype _jc_javax_crypto_SecretKeyFactorySpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_SecretKeyFactorySpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_SecretKeyFactorySpi$class_object;

#endif	/* _JC_javax_crypto_SecretKeyFactorySpi_H_ */
